input_handler

Function input_handler 

fn input_handler(
    input: Res<'_, ButtonInput<KeyCode>>,
    next_editor_state: ResMut<'_, NextState<EditorState>>,
    next_track_state: ResMut<'_, NextState<TrackEditorState>>,
)
System for switching between track editor states. Will not run when in other editors due to TrackEditorState dependency on EditorState being TrackEditor, and thus does not require a run condition.